##  Navigation and Usage Tips
In this section, you can find tips on how to navigate a Shared 360 view and work with data efficiently.
  * Switching between reports: To switch between reports for different data points or breakdowns (for example, weekly and monthly views), use the list in the upper-left corner of the report.
![Switching Between Reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274521a47a441014bfdcaab594c290cc_LowRes.png)
Switching Between Reports
  * Downloading a report: To download a report from your Shared 360 page, in the upper-right corner of the report, click the three-dot icon, then select the option that you need: Download Data (XLSX file) or Download Image (PNG file).
![Options for Downloading a Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274229b77a4410149791e42f0732aba8_LowRes.png)
Options for Downloading a Report
  * Viewing drill-down report data: To view drill-down data for a specific data point, click it on the chart. In the overlay that appears, you can view and export data if needed.
![Viewing Drill-Down Data for a Data Point](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d7af97a441014be4ab0e5be8168f4_LowRes.png)
Viewing Drill-Down Data for a Data Point


YesNo
Send
